summaryrefslogtreecommitdiff
path: root/tests/app
diff options
context:
space:
mode:
authorGreg Roach <greg@subaqua.co.uk>2020-12-31 17:25:53 +0000
committerGreg Roach <greg@subaqua.co.uk>2020-12-31 17:25:53 +0000
commit5a3d686c80adfca18cef9b4e7801f106b6c8f071 (patch)
treec41f5b69fa36759ba80bab1f273b0d16592bef40 /tests/app
parente563f71a2ec59b5b8c8626ad0e824fc8d8c4553c (diff)
downloadwebtrees-5a3d686c80adfca18cef9b4e7801f106b6c8f071.tar.gz
webtrees-5a3d686c80adfca18cef9b4e7801f106b6c8f071.tar.bz2
webtrees-5a3d686c80adfca18cef9b4e7801f106b6c8f071.zip
Tests
Diffstat (limited to 'tests/app')
-rw-r--r--tests/app/Date/AbstractCalendarDateTest.php4
-rw-r--r--tests/app/Date/FrenchDateTest.php2
-rw-r--r--tests/app/Date/GregorianDateTest.php3
-rw-r--r--tests/app/Date/HijriDateTest.php2
-rw-r--r--tests/app/Date/JalaliDateTest.php2
-rw-r--r--tests/app/Date/JewishDateTest.php2
-rw-r--r--tests/app/Date/JulianDateTest.php3
-rw-r--r--tests/app/Date/RomanDateTest.php2
-rw-r--r--tests/app/DateTest.php2
-rw-r--r--tests/app/FactTest.php2
-rw-r--r--tests/app/FamilyTest.php2
-rw-r--r--tests/app/FilterTest.php2
-rw-r--r--tests/app/FlashMessagesTest.php2
-rw-r--r--tests/app/GedcomCode/GedcomCodeAdopTest.php2
-rw-r--r--tests/app/GedcomCode/GedcomCodeNameTest.php2
-rw-r--r--tests/app/GedcomCode/GedcomCodePediTest.php2
-rw-r--r--tests/app/GedcomCode/GedcomCodeQuayTest.php2
-rw-r--r--tests/app/GedcomCode/GedcomCodeRelaTest.php2
-rw-r--r--tests/app/GedcomCode/GedcomCodeStatTest.php2
-rw-r--r--tests/app/GedcomCode/GedcomCodeTempTest.php2
-rw-r--r--tests/app/GedcomRecordTest.php2
-rw-r--r--tests/app/GedcomTagTest.php2
-rw-r--r--tests/app/IndividualTest.php2
-rw-r--r--tests/app/LogTest.php2
-rw-r--r--tests/app/MediaTest.php2
-rw-r--r--tests/app/Module/AlbumModuleTest.php2
-rw-r--r--tests/app/Module/AncestorsChartModuleTest.php2
-rw-r--r--tests/app/Module/CensusAssistantModuleTest.php2
-rw-r--r--tests/app/Module/ChartsBlockModuleTest.php2
-rw-r--r--tests/app/Module/CkeditorModuleTest.php2
-rw-r--r--tests/app/Module/ClippingsCartModuleTest.php2
-rw-r--r--tests/app/Module/CompactTreeChartModuleTest.php2
-rw-r--r--tests/app/Module/DescendancyChartModuleTest.php2
-rw-r--r--tests/app/Module/DescendancyModuleTest.php2
-rw-r--r--tests/app/Module/FamilyBookChartModuleTest.php2
-rw-r--r--tests/app/Module/FamilyNavigatorModuleTest.php2
-rw-r--r--tests/app/Module/FamilyTreeFavoritesModuleTest.php2
-rw-r--r--tests/app/Module/FamilyTreeNewsModuleTest.php2
-rw-r--r--tests/app/Module/FamilyTreeStatisticsModuleTest.php2
-rw-r--r--tests/app/Module/FanChartModuleTest.php2
-rw-r--r--tests/app/Module/FrequentlyAskedQuestionsModuleTest.php2
-rw-r--r--tests/app/Module/HourglassChartModuleTest.php2
-rw-r--r--tests/app/Module/HtmlBlockModuleTest.php2
-rw-r--r--tests/app/Module/IndividualFactsTabModuleTest.php2
-rw-r--r--tests/app/Module/IndividualMetadataModuleTest.php6
-rw-r--r--tests/app/Module/InteractiveTree/TreeViewTest.php2
-rw-r--r--tests/app/Module/InteractiveTreeModuleTest.php2
-rw-r--r--tests/app/Module/LifespansChartModuleTest.php2
-rw-r--r--tests/app/Module/LoggedInUsersModuleTest.php2
-rw-r--r--tests/app/Module/LoginBlockModuleTest.php2
-rw-r--r--tests/app/Module/MediaTabModuleTest.php2
-rw-r--r--tests/app/Module/ModuleBlockInterfaceTest.php2
-rw-r--r--tests/app/Module/ModuleChartInterfaceTest.php2
-rw-r--r--tests/app/Module/ModuleConfigInterfaceTest.php2
-rw-r--r--tests/app/Module/ModuleMenuInterfaceTest.php2
-rw-r--r--tests/app/Module/ModuleReportInterfaceTest.php2
-rw-r--r--tests/app/Module/ModuleSidebarInterfaceTest.php2
-rw-r--r--tests/app/Module/ModuleTabInterfaceTest.php2
-rw-r--r--tests/app/Module/ModuleThemeInterfaceTest.php2
-rw-r--r--tests/app/Module/NotesTabModuleTest.php2
-rw-r--r--tests/app/Module/OnThisDayModuleTest.php2
-rw-r--r--tests/app/Module/PedigreeChartModuleTest.php2
-rw-r--r--tests/app/Module/PedigreeReportModuleTest.php2
-rw-r--r--tests/app/Module/RecentChangesModuleTest.php2
-rw-r--r--tests/app/Module/RelationshipsChartModuleTest.php2
-rw-r--r--tests/app/Module/RelativesTabModuleTest.php2
-rw-r--r--tests/app/Module/ResearchTaskModuleTest.php2
-rw-r--r--tests/app/Module/ReviewChangesModuleTest.php2
-rw-r--r--tests/app/Module/SiteMapModuleTest.php2
-rw-r--r--tests/app/Module/SlideShowModuleTest.php2
-rw-r--r--tests/app/Module/SourcesTabModuleTest.php2
-rw-r--r--tests/app/Module/StatisticsChartModuleTest.php2
-rw-r--r--tests/app/Module/StoriesModuleTest.php2
-rw-r--r--tests/app/Module/ThemeSelectModuleTest.php2
-rw-r--r--tests/app/Module/TimelineChartModuleTest.php2
-rw-r--r--tests/app/Module/TopGivenNamesModuleTest.php2
-rw-r--r--tests/app/Module/TopPageViewsModuleTest.php2
-rw-r--r--tests/app/Module/TopSurnamesModuleTest.php2
-rw-r--r--tests/app/Module/UpcomingAnniversariesModuleTest.php2
-rw-r--r--tests/app/Module/UserFavoritesModuleTest.php2
-rw-r--r--tests/app/Module/UserJournalModuleTest.php2
-rw-r--r--tests/app/Module/UserMessagesModuleTest.php2
-rw-r--r--tests/app/Module/UserWelcomeModuleTest.php2
-rw-r--r--tests/app/Module/WelcomeBlockModuleTest.php2
-rw-r--r--tests/app/Module/YahrzeitModuleTest.php2
-rw-r--r--tests/app/NoteTest.php2
-rw-r--r--tests/app/PlaceTest.php2
-rw-r--r--tests/app/RepositoryTest.php2
-rw-r--r--tests/app/Services/EmailServiceTest.php4
-rw-r--r--tests/app/SoundexTest.php2
-rw-r--r--tests/app/SourceTest.php2
-rw-r--r--tests/app/StatsTest.php2
92 files changed, 188 insertions, 6 deletions
diff --git a/tests/app/Date/FrenchDateTest.php b/tests/app/Date/FrenchDateTest.php
index c051385082..6c92a580fa 100644
--- a/tests/app/Date/FrenchDateTest.php
+++ b/tests/app/Date/FrenchDateTest.php
@@ -23,6 +23,8 @@ use Fisharebest\Webtrees\TestCase;
/**
* Test harness for the class FrenchDate
+ *
+ * @covers \Fisharebest\Webtrees\Date\FrenchDate
*/
class FrenchDateTest extends TestCase
{
diff --git a/tests/app/Date/GregorianDateTest.php b/tests/app/Date/GregorianDateTest.php
index dd17d54d2b..addc5b5d34 100644
--- a/tests/app/Date/GregorianDateTest.php
+++ b/tests/app/Date/GregorianDateTest.php
@@ -23,6 +23,9 @@ use Fisharebest\Webtrees\TestCase;
/**
* Test harness for the class GregorianDate
+ *
+ * @covers \Fisharebest\Webtrees\Date\AbstractGregorianJulianDate
+ * @covers \Fisharebest\Webtrees\Date\GregorianDate
*/
class GregorianDateTest extends TestCase
{
diff --git a/tests/app/Date/HijriDateTest.php b/tests/app/Date/HijriDateTest.php
index 0ad2dbf02f..60beee2a9b 100644
--- a/tests/app/Date/HijriDateTest.php
+++ b/tests/app/Date/HijriDateTest.php
@@ -23,6 +23,8 @@ use Fisharebest\Webtrees\TestCase;
/**
* Test harness for the class \HijriDate
+ *
+ * @covers \Fisharebest\Webtrees\Date\HijriDate
*/
class HijriDateTest extends TestCase
{
diff --git a/tests/app/Date/JalaliDateTest.php b/tests/app/Date/JalaliDateTest.php
index 4144cc1b2d..5b0b9f30a6 100644
--- a/tests/app/Date/JalaliDateTest.php
+++ b/tests/app/Date/JalaliDateTest.php
@@ -23,6 +23,8 @@ use Fisharebest\Webtrees\TestCase;
/**
* Test harness for the class JalaliDate
+ *
+ * @covers \Fisharebest\Webtrees\Date\JalaliDate
*/
class JalaliDateTest extends TestCase
{
diff --git a/tests/app/Date/JewishDateTest.php b/tests/app/Date/JewishDateTest.php
index 0e3fe850f9..f36e1e7138 100644
--- a/tests/app/Date/JewishDateTest.php
+++ b/tests/app/Date/JewishDateTest.php
@@ -23,6 +23,8 @@ use Fisharebest\Webtrees\TestCase;
/**
* Test harness for the class JewishDate
+ *
+ * @covers \Fisharebest\Webtrees\Date\JewishDate
*/
class JewishDateTest extends TestCase
{
diff --git a/tests/app/Date/JulianDateTest.php b/tests/app/Date/JulianDateTest.php
index 9b906a6dae..52a49866c0 100644
--- a/tests/app/Date/JulianDateTest.php
+++ b/tests/app/Date/JulianDateTest.php
@@ -23,6 +23,9 @@ use Fisharebest\Webtrees\TestCase;
/**
* Test harness for the class JulianDate
+ *
+ * @covers \Fisharebest\Webtrees\Date\AbstractGregorianJulianDate
+ * @covers \Fisharebest\Webtrees\Date\JulianDate
*/
class JulianDateTest extends TestCase
{
diff --git a/tests/app/Date/RomanDateTest.php b/tests/app/Date/RomanDateTest.php
index 44ed993087..29f12f20ce 100644
--- a/tests/app/Date/RomanDateTest.php
+++ b/tests/app/Date/RomanDateTest.php
@@ -23,6 +23,8 @@ use Fisharebest\Webtrees\TestCase;
/**
* Test harness for the class RomanDate
+ *
+ * @covers \Fisharebest\Webtrees\Date\RomanDate
*/
class RomanDateTest extends TestCase
{
diff --git a/tests/app/DateTest.php b/tests/app/DateTest.php
index f3fe08cfb9..edac03a378 100644
--- a/tests/app/DateTest.php
+++ b/tests/app/DateTest.php
@@ -21,6 +21,8 @@ namespace Fisharebest\Webtrees;
/**
* Test harness for the class Date
+ *
+ * @covers \Fisharebest\Webtrees\Date
*/
class DateTest extends TestCase
{
diff --git a/tests/app/FactTest.php b/tests/app/FactTest.php
index 070db6c0e9..47e906b077 100644
--- a/tests/app/FactTest.php
+++ b/tests/app/FactTest.php
@@ -21,6 +21,8 @@ namespace Fisharebest\Webtrees;
/**
* Test harness for the class Fact
+ *
+ * @covers \Fisharebest\Webtrees\Fact
*/
class FactTest extends TestCase
{
diff --git a/tests/app/FamilyTest.php b/tests/app/FamilyTest.php
index d3aaa2623a..e66cf560f4 100644
--- a/tests/app/FamilyTest.php
+++ b/tests/app/FamilyTest.php
@@ -21,6 +21,8 @@ namespace Fisharebest\Webtrees;
/**
* Test harness for the class Family
+ *
+ * @covers \Fisharebest\Webtrees\Family
*/
class FamilyTest extends TestCase
{
diff --git a/tests/app/FilterTest.php b/tests/app/FilterTest.php
index 76e376ce2c..dae7171026 100644
--- a/tests/app/FilterTest.php
+++ b/tests/app/FilterTest.php
@@ -21,6 +21,8 @@ namespace Fisharebest\Webtrees;
/**
* Test harness for the class Filter
+ *
+ * @covers \Fisharebest\Webtrees\Filter
*/
class FilterTest extends TestCase
{
diff --git a/tests/app/FlashMessagesTest.php b/tests/app/FlashMessagesTest.php
index 5d10688292..dbde083928 100644
--- a/tests/app/FlashMessagesTest.php
+++ b/tests/app/FlashMessagesTest.php
@@ -21,6 +21,8 @@ namespace Fisharebest\Webtrees;
/**
* Test harness for the class FlashMessages
+ *
+ * @covers \Fisharebest\Webtrees\FlashMessages
*/
class FlashMessagesTest extends TestCase
{
diff --git a/tests/app/GedcomCode/GedcomCodeAdopTest.php b/tests/app/GedcomCode/GedcomCodeAdopTest.php
index b5431d8d68..72c9ab25fd 100644
--- a/tests/app/GedcomCode/GedcomCodeAdopTest.php
+++ b/tests/app/GedcomCode/GedcomCodeAdopTest.php
@@ -23,6 +23,8 @@ use Fisharebest\Webtrees\TestCase;
/**
* Test harness for the class GedcomCodeAdop
+ *
+ * @covers \Fisharebest\Webtrees\GedcomCode\GedcomCodeAdop
*/
class GedcomCodeAdopTest extends TestCase
{
diff --git a/tests/app/GedcomCode/GedcomCodeNameTest.php b/tests/app/GedcomCode/GedcomCodeNameTest.php
index a58833383d..f3df2255f2 100644
--- a/tests/app/GedcomCode/GedcomCodeNameTest.php
+++ b/tests/app/GedcomCode/GedcomCodeNameTest.php
@@ -23,6 +23,8 @@ use Fisharebest\Webtrees\TestCase;
/**
* Test harness for the class GedcomCodeName
+ *
+ * @covers \Fisharebest\Webtrees\GedcomCode\GedcomCodeName
*/
class GedcomCodeNameTest extends TestCase
{
diff --git a/tests/app/GedcomCode/GedcomCodePediTest.php b/tests/app/GedcomCode/GedcomCodePediTest.php
index 23521bb70b..6cf51ee8ec 100644
--- a/tests/app/GedcomCode/GedcomCodePediTest.php
+++ b/tests/app/GedcomCode/GedcomCodePediTest.php
@@ -23,6 +23,8 @@ use Fisharebest\Webtrees\TestCase;
/**
* Test harness for the class GedcomCodePedi
+ *
+ * @covers \Fisharebest\Webtrees\GedcomCode\GedcomCodePedi
*/
class GedcomCodePediTest extends TestCase
{
diff --git a/tests/app/GedcomCode/GedcomCodeQuayTest.php b/tests/app/GedcomCode/GedcomCodeQuayTest.php
index e32562587c..1b86f5d6c4 100644
--- a/tests/app/GedcomCode/GedcomCodeQuayTest.php
+++ b/tests/app/GedcomCode/GedcomCodeQuayTest.php
@@ -23,6 +23,8 @@ use Fisharebest\Webtrees\TestCase;
/**
* Test harness for the class GedcomCodeQuay
+ *
+ * @covers \Fisharebest\Webtrees\GedcomCode\GedcomCodeQuay
*/
class GedcomCodeQuayTest extends TestCase
{
diff --git a/tests/app/GedcomCode/GedcomCodeRelaTest.php b/tests/app/GedcomCode/GedcomCodeRelaTest.php
index ffdd721aef..a74a1d11c8 100644
--- a/tests/app/GedcomCode/GedcomCodeRelaTest.php
+++ b/tests/app/GedcomCode/GedcomCodeRelaTest.php
@@ -23,6 +23,8 @@ use Fisharebest\Webtrees\TestCase;
/**
* Test harness for the class GedcomCodeRela
+ *
+ * @covers \Fisharebest\Webtrees\GedcomCode\GedcomCodeRela
*/
class GedcomCodeRelaTest extends TestCase
{
diff --git a/tests/app/GedcomCode/GedcomCodeStatTest.php b/tests/app/GedcomCode/GedcomCodeStatTest.php
index 5782e37320..9f568b86cc 100644
--- a/tests/app/GedcomCode/GedcomCodeStatTest.php
+++ b/tests/app/GedcomCode/GedcomCodeStatTest.php
@@ -23,6 +23,8 @@ use Fisharebest\Webtrees\TestCase;
/**
* Test harness for the class GedcomCodeStat
+ *
+ * @covers \Fisharebest\Webtrees\GedcomCode\GedcomCodeStat
*/
class GedcomCodeStatTest extends TestCase
{
diff --git a/tests/app/GedcomCode/GedcomCodeTempTest.php b/tests/app/GedcomCode/GedcomCodeTempTest.php
index b22e4725ae..363878adff 100644
--- a/tests/app/GedcomCode/GedcomCodeTempTest.php
+++ b/tests/app/GedcomCode/GedcomCodeTempTest.php
@@ -23,6 +23,8 @@ use Fisharebest\Webtrees\TestCase;
/**
* Test harness for the class GedcomCodeTemp
+ *
+ * @covers \Fisharebest\Webtrees\GedcomCode\GedcomCodeTemp
*/
class GedcomCodeTempTest extends TestCase
{
diff --git a/tests/app/GedcomRecordTest.php b/tests/app/GedcomRecordTest.php
index ee2939bb40..9f8ef5e637 100644
--- a/tests/app/GedcomRecordTest.php
+++ b/tests/app/GedcomRecordTest.php
@@ -21,6 +21,8 @@ namespace Fisharebest\Webtrees;
/**
* Test harness for the class GedcomRecord
+ *
+ * @covers \Fisharebest\Webtrees\GedcomRecord
*/
class GedcomRecordTest extends TestCase
{
diff --git a/tests/app/GedcomTagTest.php b/tests/app/GedcomTagTest.php
index 1cb182992d..3ae1148961 100644
--- a/tests/app/GedcomTagTest.php
+++ b/tests/app/GedcomTagTest.php
@@ -21,6 +21,8 @@ namespace Fisharebest\Webtrees;
/**
* Test harness for the class GedcomTag
+ *
+ * @covers \Fisharebest\Webtrees\GedcomTag
*/
class GedcomTagTest extends TestCase
{
diff --git a/tests/app/IndividualTest.php b/tests/app/IndividualTest.php
index 2ebb927877..dafb86c6fd 100644
--- a/tests/app/IndividualTest.php
+++ b/tests/app/IndividualTest.php
@@ -21,6 +21,8 @@ namespace Fisharebest\Webtrees;
/**
* Test harness for the class Individual
+ *
+ * @covers \Fisharebest\Webtrees\Individual
*/
class IndividualTest extends TestCase
{
diff --git a/tests/app/LogTest.php b/tests/app/LogTest.php
index 0eae7e27a3..14c8f12b90 100644
--- a/tests/app/LogTest.php
+++ b/tests/app/LogTest.php
@@ -21,6 +21,8 @@ namespace Fisharebest\Webtrees;
/**
* Test harness for the class Log
+ *
+ * @covers \Fisharebest\Webtrees\Log
*/
class LogTest extends TestCase
{
diff --git a/tests/app/MediaTest.php b/tests/app/MediaTest.php
index 7535038959..2c3c908ad0 100644
--- a/tests/app/MediaTest.php
+++ b/tests/app/MediaTest.php
@@ -21,6 +21,8 @@ namespace Fisharebest\Webtrees;
/**
* Test harness for the class Media
+ *
+ * @covers \Fisharebest\Webtrees\Media
*/
class MediaTest extends TestCase
{
diff --git a/tests/app/Module/AlbumModuleTest.php b/tests/app/Module/AlbumModuleTest.php
index 0e7a51b835..42899bc604 100644
--- a/tests/app/Module/AlbumModuleTest.php
+++ b/tests/app/Module/AlbumModuleTest.php
@@ -23,6 +23,8 @@ use Fisharebest\Webtrees\TestCase;
/**
* Test harness for the class AlbumModule
+ *
+ * @covers \Fisharebest\Webtrees\Module\AlbumModule
*/
class AlbumModuleTest extends TestCase
{
diff --git a/tests/app/Module/AncestorsChartModuleTest.php b/tests/app/Module/AncestorsChartModuleTest.php
index bb77d0e083..ecbdb7041a 100644
--- a/tests/app/Module/AncestorsChartModuleTest.php
+++ b/tests/app/Module/AncestorsChartModuleTest.php
@@ -23,6 +23,8 @@ use Fisharebest\Webtrees\TestCase;
/**
* Test harness for the class AncestorsChartModule
+ *
+ * @covers \Fisharebest\Webtrees\Module\AncestorsChartModule
*/
class AncestorsChartModuleTest extends TestCase
{
diff --git a/tests/app/Module/CensusAssistantModuleTest.php b/tests/app/Module/CensusAssistantModuleTest.php
index 026a2663b3..1d88e8d456 100644
--- a/tests/app/Module/CensusAssistantModuleTest.php
+++ b/tests/app/Module/CensusAssistantModuleTest.php
@@ -23,6 +23,8 @@ use Fisharebest\Webtrees\TestCase;
/**
* Test harness for the class CensusAssistantModule
+ *
+ * @covers \Fisharebest\Webtrees\Module\CensusAssistantModule
*/
class CensusAssistantModuleTest extends TestCase
{
diff --git a/tests/app/Module/ChartsBlockModuleTest.php b/tests/app/Module/ChartsBlockModuleTest.php
index 3f822a045d..eb477112c3 100644
--- a/tests/app/Module/ChartsBlockModuleTest.php
+++ b/tests/app/Module/ChartsBlockModuleTest.php
@@ -23,6 +23,8 @@ use Fisharebest\Webtrees\TestCase;
/**
* Test harness for the class ChartsBlockModule
+ *
+ * @covers \Fisharebest\Webtrees\Module\ChartsBlockModule
*/
class ChartsBlockModuleTest extends TestCase
{
diff --git a/tests/app/Module/CkeditorModuleTest.php b/tests/app/Module/CkeditorModuleTest.php
index f3be1fce53..df397267de 100644
--- a/tests/app/Module/CkeditorModuleTest.php
+++ b/tests/app/Module/CkeditorModuleTest.php
@@ -23,6 +23,8 @@ use Fisharebest\Webtrees\TestCase;
/**
* Test harness for the class CkeditorModule
+ *
+ * @covers \Fisharebest\Webtrees\Module\CkeditorModule
*/
class CkeditorModuleTest extends TestCase
{
diff --git a/tests/app/Module/ClippingsCartModuleTest.php b/tests/app/Module/ClippingsCartModuleTest.php
index 6066bd438c..85eeb185bc 100644
--- a/tests/app/Module/ClippingsCartModuleTest.php
+++ b/tests/app/Module/ClippingsCartModuleTest.php
@@ -23,6 +23,8 @@ use Fisharebest\Webtrees\TestCase;
/**
* Test harness for the class ClippingsCartModule
+ *
+ * @covers \Fisharebest\Webtrees\Module\ClippingsCartModule
*/
class ClippingsCartModuleTest extends TestCase
{
diff --git a/tests/app/Module/CompactTreeChartModuleTest.php b/tests/app/Module/CompactTreeChartModuleTest.php
index 1c3101d8c2..7eaf7b6656 100644
--- a/tests/app/Module/CompactTreeChartModuleTest.php
+++ b/tests/app/Module/CompactTreeChartModuleTest.php
@@ -23,6 +23,8 @@ use Fisharebest\Webtrees\TestCase;
/**
* Test harness for the class CompactTreeChartModule
+ *
+ * @covers \Fisharebest\Webtrees\Module\CompactTreeChartModule
*/
class CompactTreeChartModuleTest extends TestCase
{
diff --git a/tests/app/Module/DescendancyChartModuleTest.php b/tests/app/Module/DescendancyChartModuleTest.php
index 27cd435947..065d1d60cf 100644
--- a/tests/app/Module/DescendancyChartModuleTest.php
+++ b/tests/app/Module/DescendancyChartModuleTest.php
@@ -23,6 +23,8 @@ use Fisharebest\Webtrees\TestCase;
/**
* Test harness for the class DescendancyChartModule
+ *
+ * @covers \Fisharebest\Webtrees\Module\DescendancyChartModule
*/
class DescendancyChartModuleTest extends TestCase
{
diff --git a/tests/app/Module/DescendancyModuleTest.php b/tests/app/Module/DescendancyModuleTest.php
index 958bb1552b..8fdf540a19 100644
--- a/tests/app/Module/DescendancyModuleTest.php
+++ b/tests/app/Module/DescendancyModuleTest.php
@@ -23,6 +23,8 @@ use Fisharebest\Webtrees\TestCase;
/**
* Test harness for the class DescendancyModule
+ *
+ * @covers \Fisharebest\Webtrees\Module\DescendancyModule
*/
class DescendancyModuleTest extends TestCase
{
diff --git a/tests/app/Module/FamilyBookChartModuleTest.php b/tests/app/Module/FamilyBookChartModuleTest.php
index 1fb4c23304..accfe4033b 100644
--- a/tests/app/Module/FamilyBookChartModuleTest.php
+++ b/tests/app/Module/FamilyBookChartModuleTest.php
@@ -23,6 +23,8 @@ use Fisharebest\Webtrees\TestCase;
/**
* Test harness for the class FamilyBookChartModule
+ *
+ * @covers \Fisharebest\Webtrees\Module\FamilyBookChartModule
*/
class FamilyBookChartModuleTest extends TestCase
{
diff --git a/tests/app/Module/FamilyNavigatorModuleTest.php b/tests/app/Module/FamilyNavigatorModuleTest.php
index 0332183668..020e71d77e 100644
--- a/tests/app/Module/FamilyNavigatorModuleTest.php
+++ b/tests/app/Module/FamilyNavigatorModuleTest.php
@@ -23,6 +23,8 @@ use Fisharebest\Webtrees\TestCase;
/**
* Test harness for the class FamilyNavigatorModule
+ *
+ * @covers \Fisharebest\Webtrees\Module\FamilyNavigatorModule
*/
class FamilyNavigatorModuleTest extends TestCase
{
diff --git a/tests/app/Module/FamilyTreeFavoritesModuleTest.php b/tests/app/Module/FamilyTreeFavoritesModuleTest.php
index 66f8f589c4..71071ab879 100644
--- a/tests/app/Module/FamilyTreeFavoritesModuleTest.php
+++ b/tests/app/Module/FamilyTreeFavoritesModuleTest.php
@@ -23,6 +23,8 @@ use Fisharebest\Webtrees\TestCase;
/**
* Test harness for the class FamilyTreeFavoritesModule
+ *
+ * @covers \Fisharebest\Webtrees\Module\FamilyTreeFavoritesModule
*/
class FamilyTreeFavoritesModuleTest extends TestCase
{
diff --git a/tests/app/Module/FamilyTreeNewsModuleTest.php b/tests/app/Module/FamilyTreeNewsModuleTest.php
index faecc2a863..9110df054a 100644
--- a/tests/app/Module/FamilyTreeNewsModuleTest.php
+++ b/tests/app/Module/FamilyTreeNewsModuleTest.php
@@ -23,6 +23,8 @@ use Fisharebest\Webtrees\TestCase;
/**
* Test harness for the class FamilyTreeNewsModule
+ *
+ * @covers \Fisharebest\Webtrees\Module\FamilyTreeNewsModule
*/
class FamilyTreeNewsModuleTest extends TestCase
{
diff --git a/tests/app/Module/FamilyTreeStatisticsModuleTest.php b/tests/app/Module/FamilyTreeStatisticsModuleTest.php
index af5eacf3e7..00cc0cdf0f 100644
--- a/tests/app/Module/FamilyTreeStatisticsModuleTest.php
+++ b/tests/app/Module/FamilyTreeStatisticsModuleTest.php
@@ -23,6 +23,8 @@ use Fisharebest\Webtrees\TestCase;
/**
* Test harness for the class FamilyTreeStatisticsModule
+ *
+ * @covers \Fisharebest\Webtrees\Module\FamilyTreeStatisticsModule
*/
class FamilyTreeStatisticsModuleTest extends TestCase
{
diff --git a/tests/app/Module/FanChartModuleTest.php b/tests/app/Module/FanChartModuleTest.php
index 2de9336b92..7ef5087ced 100644
--- a/tests/app/Module/FanChartModuleTest.php
+++ b/tests/app/Module/FanChartModuleTest.php
@@ -23,6 +23,8 @@ use Fisharebest\Webtrees\TestCase;
/**
* Test harness for the class FanChartModule
+ *
+ * @covers \Fisharebest\Webtrees\Module\FanChartModule
*/
class FanChartModuleTest extends TestCase
{
diff --git a/tests/app/Module/FrequentlyAskedQuestionsModuleTest.php b/tests/app/Module/FrequentlyAskedQuestionsModuleTest.php
index 3cca998a09..f6ed6c6e6a 100644
--- a/tests/app/Module/FrequentlyAskedQuestionsModuleTest.php
+++ b/tests/app/Module/FrequentlyAskedQuestionsModuleTest.php
@@ -23,6 +23,8 @@ use Fisharebest\Webtrees\TestCase;
/**
* Test harness for the class FrequentlyAskedQuestionsModule
+ *
+ * @covers \Fisharebest\Webtrees\Module\FrequentlyAskedQuestionsModule
*/
class FrequentlyAskedQuestionsModuleTest extends TestCase
{
diff --git a/tests/app/Module/HourglassChartModuleTest.php b/tests/app/Module/HourglassChartModuleTest.php
index c83e6e47ec..461ebb85fe 100644
--- a/tests/app/Module/HourglassChartModuleTest.php
+++ b/tests/app/Module/HourglassChartModuleTest.php
@@ -23,6 +23,8 @@ use Fisharebest\Webtrees\TestCase;
/**
* Test harness for the class HourglassChartModule
+ *
+ * @covers \Fisharebest\Webtrees\Module\HourglassChartModule
*/
class HourglassChartModuleTest extends TestCase
{
diff --git a/tests/app/Module/HtmlBlockModuleTest.php b/tests/app/Module/HtmlBlockModuleTest.php
index 2158acaa01..2d818d9bfc 100644
--- a/tests/app/Module/HtmlBlockModuleTest.php
+++ b/tests/app/Module/HtmlBlockModuleTest.php
@@ -23,6 +23,8 @@ use Fisharebest\Webtrees\TestCase;
/**
* Test harness for the class HtmlBlockModule
+ *
+ * @covers \Fisharebest\Webtrees\Module\HtmlBlockModule
*/
class HtmlBlockModuleTest extends TestCase
{
diff --git a/tests/app/Module/IndividualFactsTabModuleTest.php b/tests/app/Module/IndividualFactsTabModuleTest.php
index b679c7499d..7f02f6203e 100644
--- a/tests/app/Module/IndividualFactsTabModuleTest.php
+++ b/tests/app/Module/IndividualFactsTabModuleTest.php
@@ -23,6 +23,8 @@ use Fisharebest\Webtrees\TestCase;
/**
* Test harness for the class IndividualFactsTabModule
+ *
+ * @covers \Fisharebest\Webtrees\Module\IndividualFactsTabModule
*/
class IndividualFactsTabModuleTest extends TestCase
{
diff --git a/tests/app/Module/InteractiveTree/TreeViewTest.php b/tests/app/Module/InteractiveTree/TreeViewTest.php
index a7c9bff044..02475e1720 100644
--- a/tests/app/Module/InteractiveTree/TreeViewTest.php
+++ b/tests/app/Module/InteractiveTree/TreeViewTest.php
@@ -23,6 +23,8 @@ use Fisharebest\Webtrees\TestCase;
/**
* Test harness for the class TreeView
+ *
+ * @covers \Fisharebest\Webtrees\Module\InteractiveTree\TreeView
*/
class TreeViewTest extends TestCase
{
diff --git a/tests/app/Module/InteractiveTreeModuleTest.php b/tests/app/Module/InteractiveTreeModuleTest.php
index 9ab8974f15..a006b32b65 100644
--- a/tests/app/Module/InteractiveTreeModuleTest.php
+++ b/tests/app/Module/InteractiveTreeModuleTest.php
@@ -23,6 +23,8 @@ use Fisharebest\Webtrees\TestCase;
/**
* Test harness for the class InteractiveTreeModule
+ *
+ * @covers \Fisharebest\Webtrees\Module\InteractiveTreeModule
*/
class InteractiveTreeModuleTest extends TestCase
{
diff --git a/tests/app/Module/LifespansChartModuleTest.php b/tests/app/Module/LifespansChartModuleTest.php
index 343c9ea9df..cc4ffdee62 100644
--- a/tests/app/Module/LifespansChartModuleTest.php
+++ b/tests/app/Module/LifespansChartModuleTest.php
@@ -23,6 +23,8 @@ use Fisharebest\Webtrees\TestCase;
/**
* Test harness for the class LifespansChartModule
+ *
+ * @covers \Fisharebest\Webtrees\Module\LifespansChartModule
*/
class LifespansChartModuleTest extends TestCase
{
diff --git a/tests/app/Module/LoggedInUsersModuleTest.php b/tests/app/Module/LoggedInUsersModuleTest.php
index 668b828fe1..0f7bab1e85 100644
--- a/tests/app/Module/LoggedInUsersModuleTest.php
+++ b/tests/app/Module/LoggedInUsersModuleTest.php
@@ -23,6 +23,8 @@ use Fisharebest\Webtrees\TestCase;
/**
* Test harness for the class LoggedInUsersModule
+ *
+ * @covers \Fisharebest\Webtrees\Module\LoggedInUsersModule
*/
class LoggedInUsersModuleTest extends TestCase
{
diff --git a/tests/app/Module/LoginBlockModuleTest.php b/tests/app/Module/LoginBlockModuleTest.php
index 69e0c71bc9..95cbfb2d4c 100644
--- a/tests/app/Module/LoginBlockModuleTest.php
+++ b/tests/app/Module/LoginBlockModuleTest.php
@@ -23,6 +23,8 @@ use Fisharebest\Webtrees\TestCase;
/**
* Test harness for the class LoginBlockModule
+ *
+ * @covers \Fisharebest\Webtrees\Module\LoginBlockModule
*/
class LoginBlockModuleTest extends TestCase
{
diff --git a/tests/app/Module/MediaTabModuleTest.php b/tests/app/Module/MediaTabModuleTest.php
index 10872e9456..5672bdd7b3 100644
--- a/tests/app/Module/MediaTabModuleTest.php
+++ b/tests/app/Module/MediaTabModuleTest.php
@@ -23,6 +23,8 @@ use Fisharebest\Webtrees\TestCase;
/**
* Test harness for the class MediaTabModule
+ *
+ * @covers \Fisharebest\Webtrees\Module\MediaTabModule
*/
class MediaTabModuleTest extends TestCase
{
diff --git a/tests/app/Module/ModuleBlockInterfaceTest.php b/tests/app/Module/ModuleBlockInterfaceTest.php
index 8cd4276fa4..e000a5ad6c 100644
--- a/tests/app/Module/ModuleBlockInterfaceTest.php
+++ b/tests/app/Module/ModuleBlockInterfaceTest.php
@@ -23,6 +23,8 @@ use Fisharebest\Webtrees\TestCase;
/**
* Test harness for the class ModuleBlockInterface
+ *
+ * @covers \Fisharebest\Webtrees\Module\ModuleBlockInterface
*/
class ModuleBlockInterfaceTest extends TestCase
{
diff --git a/tests/app/Module/ModuleChartInterfaceTest.php b/tests/app/Module/ModuleChartInterfaceTest.php
index e73118a4de..17ac07105d 100644
--- a/tests/app/Module/ModuleChartInterfaceTest.php
+++ b/tests/app/Module/ModuleChartInterfaceTest.php
@@ -23,6 +23,8 @@ use Fisharebest\Webtrees\TestCase;
/**
* Test harness for the class ModuleChartInterface
+ *
+ * @covers \Fisharebest\Webtrees\Module\ModuleChartInterface
*/
class ModuleChartInterfaceTest extends TestCase
{
diff --git a/tests/app/Module/ModuleConfigInterfaceTest.php b/tests/app/Module/ModuleConfigInterfaceTest.php
index 4676aba5eb..c509b7fb14 100644
--- a/tests/app/Module/ModuleConfigInterfaceTest.php
+++ b/tests/app/Module/ModuleConfigInterfaceTest.php
@@ -23,6 +23,8 @@ use Fisharebest\Webtrees\TestCase;
/**
* Test harness for the class ModuleConfigInterface
+ *
+ * @covers \Fisharebest\Webtrees\Module\ModuleConfigInterface
*/
class ModuleConfigInterfaceTest extends TestCase
{
diff --git a/tests/app/Module/ModuleMenuInterfaceTest.php b/tests/app/Module/ModuleMenuInterfaceTest.php
index 00e39259ae..1df162ad72 100644
--- a/tests/app/Module/ModuleMenuInterfaceTest.php
+++ b/tests/app/Module/ModuleMenuInterfaceTest.php
@@ -23,6 +23,8 @@ use Fisharebest\Webtrees\TestCase;
/**
* Test harness for the class ModuleMenuInterface
+ *
+ * @covers \Fisharebest\Webtrees\Module\ModuleMenuInterface
*/
class ModuleMenuInterfaceTest extends TestCase
{
diff --git a/tests/app/Module/ModuleReportInterfaceTest.php b/tests/app/Module/ModuleReportInterfaceTest.php
index 63bec3badb..2a6c8a0f38 100644
--- a/tests/app/Module/ModuleReportInterfaceTest.php
+++ b/tests/app/Module/ModuleReportInterfaceTest.php
@@ -23,6 +23,8 @@ use Fisharebest\Webtrees\TestCase;
/**
* Test harness for the class ModuleReportInterface
+ *
+ * @covers \Fisharebest\Webtrees\Module\ModuleReportInterface
*/
class ModuleReportInterfaceTest extends TestCase
{
diff --git a/tests/app/Module/ModuleSidebarInterfaceTest.php b/tests/app/Module/ModuleSidebarInterfaceTest.php
index 526044c1c1..3170a719f0 100644
--- a/tests/app/Module/ModuleSidebarInterfaceTest.php
+++ b/tests/app/Module/ModuleSidebarInterfaceTest.php
@@ -23,6 +23,8 @@ use Fisharebest\Webtrees\TestCase;
/**
* Test harness for the class ModuleSidebarInterface
+ *
+ * @covers \Fisharebest\Webtrees\Module\ModuleSidebarInterface
*/
class ModuleSidebarInterfaceTest extends TestCase
{
diff --git a/tests/app/Module/ModuleTabInterfaceTest.php b/tests/app/Module/ModuleTabInterfaceTest.php
index fb2ba9a15e..1b216e5748 100644
--- a/tests/app/Module/ModuleTabInterfaceTest.php
+++ b/tests/app/Module/ModuleTabInterfaceTest.php
@@ -23,6 +23,8 @@ use Fisharebest\Webtrees\TestCase;
/**
* Test harness for the class ModuleTabInterface
+ *
+ * @covers \Fisharebest\Webtrees\Module\ModuleTabInterface
*/
class ModuleTabInterfaceTest extends TestCase
{
diff --git a/tests/app/Module/ModuleThemeInterfaceTest.php b/tests/app/Module/ModuleThemeInterfaceTest.php
index 98be5a2694..4303f8ebcd 100644
--- a/tests/app/Module/ModuleThemeInterfaceTest.php
+++ b/tests/app/Module/ModuleThemeInterfaceTest.php
@@ -23,6 +23,8 @@ use Fisharebest\Webtrees\TestCase;
/**
* Test harness for the class ModuleThemeInterface
+ *
+ * @covers \Fisharebest\Webtrees\Module\ModuleThemeInterface
*/
class ModuleThemeInterfaceTest extends TestCase
{
diff --git a/tests/app/Module/NotesTabModuleTest.php b/tests/app/Module/NotesTabModuleTest.php
index c94bb90c47..545abafcb8 100644
--- a/tests/app/Module/NotesTabModuleTest.php
+++ b/tests/app/Module/NotesTabModuleTest.php
@@ -23,6 +23,8 @@ use Fisharebest\Webtrees\TestCase;
/**
* Test harness for the class NotesTabModule
+ *
+ * @covers \Fisharebest\Webtrees\Module\NotesTabModule
*/
class NotesTabModuleTest extends TestCase
{
diff --git a/tests/app/Module/OnThisDayModuleTest.php b/tests/app/Module/OnThisDayModuleTest.php
index c2f10bf2c7..bfde39ff09 100644
--- a/tests/app/Module/OnThisDayModuleTest.php
+++ b/tests/app/Module/OnThisDayModuleTest.php
@@ -23,6 +23,8 @@ use Fisharebest\Webtrees\TestCase;
/**
* Test harness for the class OnThisDayModule
+ *
+ * @covers \Fisharebest\Webtrees\Module\OnThisDayModule
*/
class OnThisDayModuleTest extends TestCase
{
diff --git a/tests/app/Module/PedigreeChartModuleTest.php b/tests/app/Module/PedigreeChartModuleTest.php
index e56dec06dd..8baf288bc0 100644
--- a/tests/app/Module/PedigreeChartModuleTest.php
+++ b/tests/app/Module/PedigreeChartModuleTest.php
@@ -23,6 +23,8 @@ use Fisharebest\Webtrees\TestCase;
/**
* Test harness for the class PedigreeChartModule
+ *
+ * @covers \Fisharebest\Webtrees\Module\PedigreeChartModule
*/
class PedigreeChartModuleTest extends TestCase
{
diff --git a/tests/app/Module/PedigreeReportModuleTest.php b/tests/app/Module/PedigreeReportModuleTest.php
index c8d47412ec..8b1425fb83 100644
--- a/tests/app/Module/PedigreeReportModuleTest.php
+++ b/tests/app/Module/PedigreeReportModuleTest.php
@@ -33,6 +33,8 @@ use League\Flysystem\Filesystem;
/**
* Test harness for the class PedigreeReportModule
+ *
+ * @covers \Fisharebest\Webtrees\Module\PedigreeReportModule
*/
class PedigreeReportModuleTest extends TestCase
{
diff --git a/tests/app/Module/RecentChangesModuleTest.php b/tests/app/Module/RecentChangesModuleTest.php
index 6c7d03b4f6..29b5bfe033 100644
--- a/tests/app/Module/RecentChangesModuleTest.php
+++ b/tests/app/Module/RecentChangesModuleTest.php
@@ -23,6 +23,8 @@ use Fisharebest\Webtrees\TestCase;
/**
* Test harness for the class RecentChangesModule
+ *
+ * @covers \Fisharebest\Webtrees\Module\RecentChangesModule
*/
class RecentChangesModuleTest extends TestCase
{
diff --git a/tests/app/Module/RelationshipsChartModuleTest.php b/tests/app/Module/RelationshipsChartModuleTest.php
index 4d2e93fce7..f5d91cf911 100644
--- a/tests/app/Module/RelationshipsChartModuleTest.php
+++ b/tests/app/Module/RelationshipsChartModuleTest.php
@@ -23,6 +23,8 @@ use Fisharebest\Webtrees\TestCase;
/**
* Test harness for the class RelationshipsChartModule
+ *
+ * @covers \Fisharebest\Webtrees\Module\RelationshipsChartModule
*/
class RelationshipsChartModuleTest extends TestCase
{
diff --git a/tests/app/Module/RelativesTabModuleTest.php b/tests/app/Module/RelativesTabModuleTest.php
index 8e9652db2c..0c82220990 100644
--- a/tests/app/Module/RelativesTabModuleTest.php
+++ b/tests/app/Module/RelativesTabModuleTest.php
@@ -23,6 +23,8 @@ use Fisharebest\Webtrees\TestCase;
/**
* Test harness for the class RelativesTabModule
+ *
+ * @covers \Fisharebest\Webtrees\Module\RelativesTabModule
*/
class RelativesTabModuleTest extends TestCase
{
diff --git a/tests/app/Module/ResearchTaskModuleTest.php b/tests/app/Module/ResearchTaskModuleTest.php
index a93d2925e1..3735021f0f 100644
--- a/tests/app/Module/ResearchTaskModuleTest.php
+++ b/tests/app/Module/ResearchTaskModuleTest.php
@@ -23,6 +23,8 @@ use Fisharebest\Webtrees\TestCase;
/**
* Test harness for the class ResearchTaskModule
+ *
+ * @covers \Fisharebest\Webtrees\Module\ResearchTaskModule
*/
class ResearchTaskModuleTest extends TestCase
{
diff --git a/tests/app/Module/ReviewChangesModuleTest.php b/tests/app/Module/ReviewChangesModuleTest.php
index 9f747750c5..b855d85677 100644
--- a/tests/app/Module/ReviewChangesModuleTest.php
+++ b/tests/app/Module/ReviewChangesModuleTest.php
@@ -23,6 +23,8 @@ use Fisharebest\Webtrees\TestCase;
/**
* Test harness for the class ReviewChangesModule
+ *
+ * @covers \Fisharebest\Webtrees\Module\ReviewChangesModule
*/
class ReviewChangesModuleTest extends TestCase
{
diff --git a/tests/app/Module/SiteMapModuleTest.php b/tests/app/Module/SiteMapModuleTest.php
index c13ad656bc..ddcbd8cee5 100644
--- a/tests/app/Module/SiteMapModuleTest.php
+++ b/tests/app/Module/SiteMapModuleTest.php
@@ -23,6 +23,8 @@ use Fisharebest\Webtrees\TestCase;
/**
* Test harness for the class SiteMapModule
+ *
+ * @covers \Fisharebest\Webtrees\Module\SiteMapModule
*/
class SiteMapModuleTest extends TestCase
{
diff --git a/tests/app/Module/SlideShowModuleTest.php b/tests/app/Module/SlideShowModuleTest.php
index 7da3209128..f9bc22fa59 100644
--- a/tests/app/Module/SlideShowModuleTest.php
+++ b/tests/app/Module/SlideShowModuleTest.php
@@ -23,6 +23,8 @@ use Fisharebest\Webtrees\TestCase;
/**
* Test harness for the class SlideShowModule
+ *
+ * @covers \Fisharebest\Webtrees\Module\SlideShowModule
*/
class SlideShowModuleTest extends TestCase
{
diff --git a/tests/app/Module/SourcesTabModuleTest.php b/tests/app/Module/SourcesTabModuleTest.php
index 59af570034..4dc05578df 100644
--- a/tests/app/Module/SourcesTabModuleTest.php
+++ b/tests/app/Module/SourcesTabModuleTest.php
@@ -23,6 +23,8 @@ use Fisharebest\Webtrees\TestCase;
/**
* Test harness for the class SourcesTabModule
+ *
+ * @covers \Fisharebest\Webtrees\Module\SourcesTabModule
*/
class SourcesTabModuleTest extends TestCase
{
diff --git a/tests/app/Module/StatisticsChartModuleTest.php b/tests/app/Module/StatisticsChartModuleTest.php
index f3ae444963..2cc569e0e7 100644
--- a/tests/app/Module/StatisticsChartModuleTest.php
+++ b/tests/app/Module/StatisticsChartModuleTest.php
@@ -23,6 +23,8 @@ use Fisharebest\Webtrees\TestCase;
/**
* Test harness for the class StatisticsChartModule
+ *
+ * @covers \Fisharebest\Webtrees\Module\StatisticsChartModule
*/
class StatisticsChartModuleTest extends TestCase
{
diff --git a/tests/app/Module/StoriesModuleTest.php b/tests/app/Module/StoriesModuleTest.php
index 47f2b98de0..1748c62a5e 100644
--- a/tests/app/Module/StoriesModuleTest.php
+++ b/tests/app/Module/StoriesModuleTest.php
@@ -23,6 +23,8 @@ use Fisharebest\Webtrees\TestCase;
/**
* Test harness for the class StoriesModule
+ *
+ * @covers \Fisharebest\Webtrees\Module\StoriesModule
*/
class StoriesModuleTest extends TestCase
{
diff --git a/tests/app/Module/ThemeSelectModuleTest.php b/tests/app/Module/ThemeSelectModuleTest.php
index f23770aab3..96815a9603 100644
--- a/tests/app/Module/ThemeSelectModuleTest.php
+++ b/tests/app/Module/ThemeSelectModuleTest.php
@@ -23,6 +23,8 @@ use Fisharebest\Webtrees\TestCase;
/**
* Test harness for the class ThemeSelectModule
+ *
+ * @covers \Fisharebest\Webtrees\Module\ThemeSelectModule
*/
class ThemeSelectModuleTest extends TestCase
{
diff --git a/tests/app/Module/TimelineChartModuleTest.php b/tests/app/Module/TimelineChartModuleTest.php
index a199919a4e..b71836c687 100644
--- a/tests/app/Module/TimelineChartModuleTest.php
+++ b/tests/app/Module/TimelineChartModuleTest.php
@@ -23,6 +23,8 @@ use Fisharebest\Webtrees\TestCase;
/**
* Test harness for the class TimelineChartModule
+ *
+ * @covers \Fisharebest\Webtrees\Module\TimelineChartModule
*/
class TimelineChartModuleTest extends TestCase
{
diff --git a/tests/app/Module/TopGivenNamesModuleTest.php b/tests/app/Module/TopGivenNamesModuleTest.php
index 9767ad1296..a3a30a8b2b 100644
--- a/tests/app/Module/TopGivenNamesModuleTest.php
+++ b/tests/app/Module/TopGivenNamesModuleTest.php
@@ -23,6 +23,8 @@ use Fisharebest\Webtrees\TestCase;
/**
* Test harness for the class TopGivenNamesModule
+ *
+ * @covers \Fisharebest\Webtrees\Module\TopGivenNamesModule
*/
class TopGivenNamesModuleTest extends TestCase
{
diff --git a/tests/app/Module/TopPageViewsModuleTest.php b/tests/app/Module/TopPageViewsModuleTest.php
index 0270dd2901..d214657f0a 100644
--- a/tests/app/Module/TopPageViewsModuleTest.php
+++ b/tests/app/Module/TopPageViewsModuleTest.php
@@ -23,6 +23,8 @@ use Fisharebest\Webtrees\TestCase;
/**
* Test harness for the class TopPageViewsModule
+ *
+ * @covers \Fisharebest\Webtrees\Module\TopPageViewsModule
*/
class TopPageViewsModuleTest extends TestCase
{
diff --git a/tests/app/Module/TopSurnamesModuleTest.php b/tests/app/Module/TopSurnamesModuleTest.php
index e4e4826c88..ac7cac2718 100644
--- a/tests/app/Module/TopSurnamesModuleTest.php
+++ b/tests/app/Module/TopSurnamesModuleTest.php
@@ -23,6 +23,8 @@ use Fisharebest\Webtrees\TestCase;
/**
* Test harness for the class TopSurnamesModule
+ *
+ * @covers \Fisharebest\Webtrees\Module\TopSurnamesModule
*/
class TopSurnamesModuleTest extends TestCase
{
diff --git a/tests/app/Module/UpcomingAnniversariesModuleTest.php b/tests/app/Module/UpcomingAnniversariesModuleTest.php
index 489d22c261..5035818488 100644
--- a/tests/app/Module/UpcomingAnniversariesModuleTest.php
+++ b/tests/app/Module/UpcomingAnniversariesModuleTest.php
@@ -23,6 +23,8 @@ use Fisharebest\Webtrees\TestCase;
/**
* Test harness for the class UpcomingAnniversariesModule
+ *
+ * @covers \Fisharebest\Webtrees\Module\UpcomingAnniversariesModule
*/
class UpcomingAnniversariesModuleTest extends TestCase
{
diff --git a/tests/app/Module/UserFavoritesModuleTest.php b/tests/app/Module/UserFavoritesModuleTest.php
index 964c7a82ea..2620146ead 100644
--- a/tests/app/Module/UserFavoritesModuleTest.php
+++ b/tests/app/Module/UserFavoritesModuleTest.php
@@ -23,6 +23,8 @@ use Fisharebest\Webtrees\TestCase;
/**
* Test harness for the class UserFavoritesModule
+ *
+ * @covers \Fisharebest\Webtrees\Module\UserFavoritesModule
*/
class UserFavoritesModuleTest extends TestCase
{
diff --git a/tests/app/Module/UserJournalModuleTest.php b/tests/app/Module/UserJournalModuleTest.php
index dc8f32112f..0b3f317988 100644
--- a/tests/app/Module/UserJournalModuleTest.php
+++ b/tests/app/Module/UserJournalModuleTest.php
@@ -23,6 +23,8 @@ use Fisharebest\Webtrees\TestCase;
/**
* Test harness for the class UserJournalModule
+ *
+ * @covers \Fisharebest\Webtrees\Module\UserJournalModule
*/
class UserJournalModuleTest extends TestCase
{
diff --git a/tests/app/Module/UserMessagesModuleTest.php b/tests/app/Module/UserMessagesModuleTest.php
index 43908efaf8..ce30a1b340 100644
--- a/tests/app/Module/UserMessagesModuleTest.php
+++ b/tests/app/Module/UserMessagesModuleTest.php
@@ -23,6 +23,8 @@ use Fisharebest\Webtrees\TestCase;
/**
* Test harness for the class UserMessagesModule
+ *
+ * @covers \Fisharebest\Webtrees\Module\UserMessagesModule
*/
class UserMessagesModuleTest extends TestCase
{
diff --git a/tests/app/Module/UserWelcomeModuleTest.php b/tests/app/Module/UserWelcomeModuleTest.php
index 03828237f9..42f46f89f4 100644
--- a/tests/app/Module/UserWelcomeModuleTest.php
+++ b/tests/app/Module/UserWelcomeModuleTest.php
@@ -23,6 +23,8 @@ use Fisharebest\Webtrees\TestCase;
/**
* Test harness for the class UserWelcomeModule
+ *
+ * @covers \Fisharebest\Webtrees\Module\UserWelcomeModule
*/
class UserWelcomeModuleTest extends TestCase
{
diff --git a/tests/app/Module/WelcomeBlockModuleTest.php b/tests/app/Module/WelcomeBlockModuleTest.php
index f29ad4aa31..005be2c705 100644
--- a/tests/app/Module/WelcomeBlockModuleTest.php
+++ b/tests/app/Module/WelcomeBlockModuleTest.php
@@ -23,6 +23,8 @@ use Fisharebest\Webtrees\TestCase;
/**
* Test harness for the class WelcomeBlockModule
+ *
+ * @covers \Fisharebest\Webtrees\Module\WelcomeBlockModule
*/
class WelcomeBlockModuleTest extends TestCase
{
diff --git a/tests/app/Module/YahrzeitModuleTest.php b/tests/app/Module/YahrzeitModuleTest.php
index 12b9683fb4..de7a8cae48 100644
--- a/tests/app/Module/YahrzeitModuleTest.php
+++ b/tests/app/Module/YahrzeitModuleTest.php
@@ -23,6 +23,8 @@ use Fisharebest\Webtrees\TestCase;
/**
* Test harness for the class YahrzeitModule
+ *
+ * @covers \Fisharebest\Webtrees\Module\YahrzeitModule
*/
class YahrzeitModuleTest extends TestCase
{
diff --git a/tests/app/NoteTest.php b/tests/app/NoteTest.php
index bf26a6a61b..0ca24652c3 100644
--- a/tests/app/NoteTest.php
+++ b/tests/app/NoteTest.php
@@ -21,6 +21,8 @@ namespace Fisharebest\Webtrees;
/**
* Test harness for the class Note
+ *
+ * @covers \Fisharebest\Webtrees\Note
*/
class NoteTest extends TestCase
{
diff --git a/tests/app/PlaceTest.php b/tests/app/PlaceTest.php
index 085180085f..14403b5e3a 100644
--- a/tests/app/PlaceTest.php
+++ b/tests/app/PlaceTest.php
@@ -21,6 +21,8 @@ namespace Fisharebest\Webtrees;
/**
* Test harness for the class Place
+ *
+ * @covers \Fisharebest\Webtrees\Place
*/
class PlaceTest extends TestCase
{
diff --git a/tests/app/RepositoryTest.php b/tests/app/RepositoryTest.php
index 94a6eac67b..ba883759a2 100644
--- a/tests/app/RepositoryTest.php
+++ b/tests/app/RepositoryTest.php
@@ -21,6 +21,8 @@ namespace Fisharebest\Webtrees;
/**
* Test harness for the class Repository
+ *
+ * @covers \Fisharebest\Webtrees\Repository
*/
class RepositoryTest extends TestCase
{
diff --git a/tests/app/Services/EmailServiceTest.php b/tests/app/Services/EmailServiceTest.php
index ed2e52c847..842588d6ed 100644
--- a/tests/app/Services/EmailServiceTest.php
+++ b/tests/app/Services/EmailServiceTest.php
@@ -23,8 +23,10 @@ use Fisharebest\Webtrees\Services\EmailService;
/**
* Test harness for the class MailService
+ *
+ * @covers \Fisharebest\Webtrees\Services\EmailService
*/
-class MailServiceTest extends TestCase
+class EmailServiceTest extends TestCase
{
/**
* Test that the class exists
diff --git a/tests/app/SoundexTest.php b/tests/app/SoundexTest.php
index 6402a8f806..7d059f1185 100644
--- a/tests/app/SoundexTest.php
+++ b/tests/app/SoundexTest.php
@@ -21,6 +21,8 @@ namespace Fisharebest\Webtrees;
/**
* Test harness for the class Soundex
+ *
+ * @covers \Fisharebest\Webtrees\Soundex
*/
class SoundexTest extends TestCase
{
diff --git a/tests/app/SourceTest.php b/tests/app/SourceTest.php
index 5840f5d8d7..f1b358e7ea 100644
--- a/tests/app/SourceTest.php
+++ b/tests/app/SourceTest.php
@@ -21,6 +21,8 @@ namespace Fisharebest\Webtrees;
/**
* Test harness for the class Source
+ *
+ * @covers \Fisharebest\Webtrees\Source
*/
class SourceTest extends TestCase
{
diff --git a/tests/app/StatsTest.php b/tests/app/StatsTest.php
index 1f3a068b1b..5932f7bf8a 100644
--- a/tests/app/StatsTest.php
+++ b/tests/app/StatsTest.php
@@ -21,6 +21,8 @@ namespace Fisharebest\Webtrees;
/**
* Test harness for the class Stats
+ *
+ * @covers \Fisharebest\Webtrees\Statistics
*/
class StatsTest extends TestCase
{
diff --git a/tests/app/Date/AbstractCalendarDateTest.php b/tests/app/Date/AbstractCalendarDateTest.php
index acc19b1e43..fab389fa6b 100644
--- a/tests/app/Date/AbstractCalendarDateTest.php
+++ b/tests/app/Date/AbstractCalendarDateTest.php
@@ -22,9 +22,9 @@ namespace Fisharebest\Webtrees\Date;
use Fisharebest\Webtrees\TestCase;
/**
* Test harness for the class CalendarDate
*/
-class CalendarDateTest extends TestCase
+class AbstractCalendarDateTest extends TestCase
{
/**
* @covers \Fisharebest\Webtrees\Date\AbstractCalendarDate::ageDifference
@@ -22,9 +22,9 @@ namespace Fisharebest\Webtrees\Date;
use Fisharebest\Webtrees\TestCase;
/**
- * Test harness for the class CalendarDate
+ * Test harness for the class AbstractCalendarDate
*/
diff --git a/tests/app/Module/IndividualMetadataModuleTest.php b/tests/app/Module/IndividualMetadataModuleTest.php
index 31ac896d67..1d0f171c8f 100644
--- a/tests/app/Module/IndividualMetadataModuleTest.php
+++ b/tests/app/Module/IndividualMetadataModuleTest.php
@@ -22,11 +22,11 @@ namespace Fisharebest\Webtrees\Module;
use Fisharebest\Webtrees\TestCase;
/**
* Test harness for the class ExtraInformationModule
*
- * @covers \Fisharebest\Webtrees\Module\ExtraInformationModule
+ * @covers \Fisharebest\Webtrees\Module\IndividualMetadataModule
*/
-class ExtraInformationModuleTest extends TestCase
+class IndividualMetadataModuleTest extends TestCase
{
/**
* Test that the class exists
@@ -22,11 +22,11 @@ namespace Fisharebest\Webtrees\Module;
use Fisharebest\Webtrees\TestCase;
/**
- * Test harness for the class ExtraInformationModule
+ * Test harness for the class IndividualMetadataModule
*